/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.agent.mapper;

import org.apache.ibatis.annotations.Select;
import top.continew.starter.data.mybatis.plus.base.BaseMapper;
import com.zayac.admin.agent.model.entity.StatsDO;

import java.time.LocalDate;

/**
 * 代理每日数据 Mapper
 *
 * @author zayac
 * @since 2024/06/04 17:10
 */
public interface DailyStatsMapper extends BaseMapper<StatsDO> {
    /**
     * 查询查询新注册总数
     *
     * @param topAgentName 上级代理线
     * @param date         日期
     * @return int
     */
    @Select("select COALESCE(sum(is_new), 0) from (select distinct agent_name, is_new from agent_stats where top_agent_name = #{topAgentName} and statics_date = #{date}) as distinct_agents")
    int selectCountByTopAgentNameAndDate(String topAgentName, LocalDate date);
}