/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.agent.model.resp;

import java.io.Serial;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.math.BigDecimal;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;

import top.continew.starter.extension.crud.model.resp.BaseDetailResp;

/**
 * 代理每日数据详情信息
 *
 * @author zayac
 * @since 2024/06/04 17:10
 */
@Data
@ExcelIgnoreUnannotated
@Schema(description = "代理每日数据详情信息")
public class StatsDetailResp extends BaseDetailResp {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 日期
     */
    @Schema(description = "日期")
    @ExcelProperty(value = "日期")
    private LocalDate staticsDate;

    /**
     * 代理id
     */
    @Schema(description = "代理id")
    @ExcelProperty(value = "代理id")
    private Long agentId;

    /**
     * 代理类型
     */
    @Schema(description = "代理类型")
    @ExcelProperty(value = "代理类型")
    private Integer agentType;

    /**
     * 代理推荐码
     */
    @Schema(description = "代理推荐码")
    @ExcelProperty(value = "代理推荐码")
    private String agentCode;

    /**
     * 代理名称
     */
    @Schema(description = "代理名称")
    @ExcelProperty(value = "代理名称")
    private String agentName;

    /**
     * 注册人数
     */
    @Schema(description = "注册人数")
    @ExcelProperty(value = "注册人数")
    private Integer isNew;

    /**
     * 首存人数
     */
    @Schema(description = "首存人数")
    @ExcelProperty(value = "首存人数")
    private BigDecimal firstDeposit;

    /**
     * 投注额
     */
    @Schema(description = "投注额")
    @ExcelProperty(value = "投注额")
    private BigDecimal deposit;

    /**
     * 投注红利
     */
    @Schema(description = "投注红利")
    @ExcelProperty(value = "投注红利")
    private BigDecimal depositPromo;

    /**
     * 取款
     */
    @Schema(description = "取款")
    @ExcelProperty(value = "取款")
    private BigDecimal draw;

    /**
     * 返水
     */
    @Schema(description = "返水")
    @ExcelProperty(value = "返水")
    private BigDecimal promo;

    /**
     * 返水比例
     */
    @Schema(description = "返水比例")
    @ExcelProperty(value = "返水比例")
    private BigDecimal promoDividend;

    /**
     * 
     */
    @Schema(description = "")
    @ExcelProperty(value = "")
    private BigDecimal rebate;

    /**
     * 账号调整
     */
    @Schema(description = "账号调整")
    @ExcelProperty(value = "账号调整")
    private BigDecimal adjust;

    /**
     * 风险等级
     */
    @Schema(description = "风险等级")
    @ExcelProperty(value = "风险等级")
    private BigDecimal riskAdjust;

    /**
     * 有效投注额
     */
    @Schema(description = "有效投注额")
    @ExcelProperty(value = "有效投注额")
    private BigDecimal bets;

    /**
     * 输赢
     */
    @Schema(description = "输赢")
    @ExcelProperty(value = "输赢")
    private BigDecimal profit;

    /**
     * 总投注额
     */
    @Schema(description = "总投注额")
    @ExcelProperty(value = "总投注额")
    private BigDecimal allBets;

    /**
     * 首存人数
     */
    @Schema(description = "首存人数")
    @ExcelProperty(value = "首存人数")
    private Integer firstCount;

    /**
     * 存款人数
     */
    @Schema(description = "存款人数")
    @ExcelProperty(value = "存款人数")
    private Integer countDeposit;

    /**
     * 取款人数
     */
    @Schema(description = "取款人数")
    @ExcelProperty(value = "取款人数")
    private Integer countDraw;

    /**
     * 投注人数
     */
    @Schema(description = "投注人数")
    @ExcelProperty(value = "投注人数")
    private Integer countBets;

    /**
     * 创建日期
     */
    @Schema(description = "创建日期")
    @ExcelProperty(value = "创建日期")
    private LocalDateTime createdAt;

    /**
     * 更新日期
     */
    @Schema(description = "更新日期")
    @ExcelProperty(value = "更新日期")
    private LocalDateTime updatedAt;

    /**
     * 
     */
    @Schema(description = "")
    @ExcelProperty(value = "")
    private BigDecimal oldDeposit;

    /**
     * 
     */
    @Schema(description = "")
    @ExcelProperty(value = "")
    private Integer oldDepositCount;

    /**
     * 
     */
    @Schema(description = "")
    @ExcelProperty(value = "")
    private BigDecimal newDeposit;
}