/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.req;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * 会员管理界面 请求参数
 */

/**
 * {
 * "pageNum": 1,
 * "pageSize": 10,
 * "registerSort": -1,
 * "drawSort": -1,
 * "depositSort": -1,
 * "lastLoginTimeSort": -1,
 * "name": "",
 * "minPay": null,
 * "maxPay": null,
 * "startDate": "2024-04-01",
 * "registerStartDate": "2024-04-25",
 * "endDate": "2024-04-25",
 * "registerEndDate": "2024-04-25",
 * "firstPayStartTime": "",
 * "firstPayEndTime": "",
 * "isBet": "",
 * "status": -1,
 * "isRest": false,
 * "tagsIds": [
 * "20000005181",
 * "20000005479",
 * "20000008037"
 * ],
 * "tagsFlag": "1"
 * }
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
public class MemberListReq {
    @Builder.Default
    private int pageNum = 1;
    @Builder.Default
    private int pageSize = 10;

    //注册时间排序
    @Builder.Default
    private int registerSort = -1;

    //提款排序
    @Builder.Default
    private int drawSort = -1;

    //存款排序
    @Builder.Default
    private int depositSort = -1;

    //最后登录时间排序
    @Builder.Default
    private int lastLoginTimeSort = -1;

    //会员账号
    private String name;

    //存款金额 最小金额
    private Double minPay;

    //存款金额 最大金额
    private Double maxPay;

    //统计时间 开始日期
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate startDate;

    //统计时间 结束日期
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate endDate;

    //注册起始日期
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate registerStartDate;

    //注册结束日期
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate registerEndDate;

    //首次存款起始时间
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime firstPayStartTime;

    //首次存款结束时间
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime firstPayEndTime;

    //是否投注 默认空 1投注 0未投注
    private String isBet;

    //状态 -1 全部 1 正常 0禁用
    @Builder.Default
    private int status = -1;

    // 重置
    @Builder.Default
    private boolean isRest = false;

    // 标签id 不传或为空查询所有
    @Builder.Default
    private List<String> tagsIds = new ArrayList<>();

    // 未知
    @Builder.Default
    private String tagsFlag = "1";
}
