/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.utils;

import cn.hutool.core.bean.BeanUtil;
import com.zayac.admin.resp.team.Team;
import com.zayac.admin.resp.team.TeamAccount;
import com.zayac.admin.resp.team.TeamAccountWithChange;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

public class CommonUtils {
    public static List<TeamAccountWithChange> findChangedTeamAccount(Team prevTeam, Team currTeam) {
        Map<Long, TeamAccount> team2AccountMap = currTeam.getList()
                .stream()
                .collect(Collectors.toMap(TeamAccount::getId, account -> account));

        return prevTeam.getList()
                .stream()
                .filter(account1 -> team2AccountMap.containsKey(account1.getId()))
                .map(account1 -> {
                    TeamAccount account2 = team2AccountMap.get(account1.getId());
                    TeamAccountWithChange changedAccount = new TeamAccountWithChange();
                    BeanUtil.copyProperties(account2, changedAccount);
                    if (account1.getFirstDepositNum() != account2.getFirstDepositNum()) {
                        changedAccount.setNewDepositNum(account2.getFirstDepositNum() - account1.getFirstDepositNum());
                    }
                    if (account1.getSubMemberNum() != account2.getSubMemberNum()) {
                        changedAccount.setNewRegisterNum(account2.getSubMemberNum() - account1.getSubMemberNum());
                    }
                    return changedAccount;
                })
                .collect(Collectors.toList());
    }


    public static <T> List<T> getLastNElements(List<T> list, int n) {
        if (list == null || list.isEmpty() || n <= 0) {
            return Collections.emptyList();
        }

        int size = list.size();
        if (n > size) {
            return new ArrayList<>(list);
        }

        return new ArrayList<>(list.subList(size - n, size));
    }
}
