/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.system.model.req;

import java.io.Serial;

import com.zayac.admin.common.enums.DisEnableStatusEnum;
import jakarta.validation.constraints.*;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import org.hibernate.validator.constraints.Length;

import top.continew.starter.extension.crud.model.req.BaseReq;

/**
 * 创建或修改平台信息
 *
 * @author zayac
 * @since 2024/05/14 12:28
 */
@Data
@Schema(description = "创建或修改平台信息")
public class PlatformReq extends BaseReq {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 平台名称
     */
    @Schema(description = "平台名称")
    @NotBlank(message = "平台名称不能为空")
    @Length(max = 100, message = "平台名称长度不能超过 {max} 个字符")
    private String name;

    /**
     * 平台别称
     */
    @Schema(description = "平台别称")
    @NotBlank(message = "平台别称不能为空")
    @Length(max = 100, message = "平台别称长度不能超过 {max} 个字符")
    private String nickname;

    /**
     * 平台地址
     */
    @Schema(description = "平台地址")
    @NotBlank(message = "平台地址不能为空")
    @Length(max = 100, message = "平台地址长度不能超过 {max} 个字符")
    private String url;

    /**
     * 平台代码
     */
    @Schema(description = "平台代码")
    @NotNull(message = "平台代码不能为空")
    private Integer code;

    /**
     * 状态(1启用,2禁用)
     */
    @Schema(description = "平台状态（1：启用；2：禁用）", type = "Integer", allowableValues = {"1", "2"}, example = "1")
    @NotNull(message = "平台状态非法")
    private DisEnableStatusEnum status;

    /**
     * 描述
     */
    @Length(max = 200, message = "平台描述长度不能超过 {max} 个字符")
    private String description;
}